![output-onlineasciitools](https://user-images.githubusercontent.com/4304794/116912589-b806ac80-ac48-11eb-9094-813a0502eb94.png)

[![PyPI version](https://badge.fury.io/py/dbt-sugar.svg)](https://badge.fury.io/py/dbt-sugar)

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
![python](https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8%20%7C%203.9-blue)

![Build](https://github.com/bitpicky/dbt-sugar/actions/workflows/main_ci.yml/badge.svg)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/bitpicky/dbt-sugar/main.svg)](https://results.pre-commit.ci/latest/github/bitpicky/dbt-sugar/main)
[![codecov](https://codecov.io/gh/bitpicky/dbt-sugar/branch/main/graph/badge.svg?token=JB0E0LZDW1)](https://codecov.io/gh/bitpicky/dbt-sugar)
[![Maintainability](https://api.codeclimate.com/v1/badges/1e6a887de605ef8e0eca/maintainability)](https://codeclimate.com/github/bitpicky/dbt-sugar/maintainability)

[![Downloads](https://pepy.tech/badge/dbt-sugar)](https://pepy.tech/project/dbt-sugar)
[![Discord](https://img.shields.io/discord/752101657218908281?label=discord)](https://discord.gg/cQB49ejbCA)

Documentation on [gitbook](https://bitpicky.gitbook.io/dbt-sugar/)

If you want to help out and join the party feel free to:

- [create an issue](https://github.com/bitpicky/dbt-sugar/issues) or more fun
- join us on [Discord](https://discord.gg/cQB49ejbCA) :sparkles: and
- check the [ROADMAP.md](ROADMAP.md) to see what's in the plans.

# dbt-sugar :candy:

:warning: **dbt-sugar is pretty alpha, don't use on your prod models unless you have tested it in a safe place before.**

## What is dbt-sugar?

dbt-sugar is a CLI tool that allows users of [dbt](https://www.getdbt.com/) to have fun and ease performing actions around dbt models such as:

- documentation
- test enforcement
  and probably more in a not too distant future.

  We keep track of our progress in the [projects](https://github.com/bitpicky/dbt-sugar/projects) section.
